;;; loaddefs.el --- automatically extracted autoloads
;;
;;; Code:


;;;### (autoloads (perl-minlint-run perl-minlint-mode) "perl-minlint"
;;;;;;  "perl-minlint.el" (21434 26488 351857 56000))
;;; Generated autoloads from perl-minlint.el

(autoload 'perl-minlint-mode "perl-minlint" "\
Run perlminlint in after-save-hook.

\(fn &optional ARG)" t nil)

(autoload 'perl-minlint-run "perl-minlint" "\
Run perlminlint for current buffer.
By default, this runs only in perl-minlint-mode.
To use this in other mode, please give t for optional argument FORCE.

\(fn &optional FORCE)" t nil)

;;;***

(provide 'loaddefs)
;; Local Variables:
;; version-control: never
;; no-byte-compile: t
;; no-update-autoloads: t
;; coding: utf-8
;; End:
;;; loaddefs.el ends here
